Kernel-based 'Tweedie' compound Poisson gamma model using high-dimensional predictors for the analyses of zero-inflated response variables. The package features built-in estimation, prediction and cross-validation tools and supports choice of different kernel functions. For more details, please see Yi Lian, Archer Yi Yang, Boxiang Wang, Peng Shi & Robert William Platt (2023) tools:::Rd_expr_doi("10.1080/00401706.2022.2156615").
Maintainer: Yi Lian yi.lian@mail.mcgill.ca
Authors:
Archer Yi Yang [copyright holder]
Boxiang Wang
Peng Shi
Robert W. Platt